pub enum PayloadForm {
Eval,
Coeff,
}Expand description
The form of a payload dictates what conversion, if any, must be performed when creating a blob from the payload.
Variants
Eval
Evaluation form, where the payload is in evaluation form.
Coeff
Coefficient form, where the payload is in coefficient form.